@@ -11,19 +11,22 @@
 #include <QCommandLineParser>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QQmlExtensionPlugin>
 #include <QQuickWindow>
 #include <QSurfaceFormat>
-#include <QUrl>
 
 #include <KAboutData>
 #include <KDBusService>
 #include <KLocalizedContext>
+#include <KLocalizedQmlContext>
 #include <KLocalizedString>
 #include <KWindowSystem>
 
-#include "controller.h"
+#include "app.h"
 #include "plasma-welcome-version.h"
-#include <KLocalizedQmlContext>
+
+// Ensure the public plugin is linked by referencing exported symbol
+Q_IMPORT_QML_PLUGIN(org_kde_plasma_welcomePlugin);
 
 int main(int argc, char *argv[])
 {
@@ -71,7 +74,6 @@ int main(int argc, char *argv[])
     aboutData.setupCommandLine(&parser);
 
     parser.addOption(QCommandLineOption(QStringLiteral("post-update"), i18n("Display release notes for the current Plasma release.")));
-    parser.addOption(QCommandLineOption(QStringLiteral("post-update-beta"), i18n("Display release notes for the current Plasma release, for beta versions.")));
     parser.addOption(QCommandLineOption(QStringLiteral("live-environment"), i18n("Display the live page intended for distro live environments.")));
 
     QCommandLineOption pagesOption(QStringLiteral("pages"),
@@ -100,30 +102,27 @@ int main(int argc, char *argv[])
     });
 
     // Tell QML about requested mode/pages
-    auto controller = engine.singletonInstance<Controller *>("org.kde.plasma.welcome", "Controller");
+    auto appSingleton = engine.singletonInstance<App *>("org.kde.plasma.welcome.private", "App");
     if (parser.isSet(QStringLiteral("pages"))) {
         QStringList pages = parser.value(pagesOption).split(",");
-
-        // Ensure each page ends with ".qml"
-        for (QString &page : pages) {
-            if (!page.endsWith(".qml")) {
-                page.append(".qml");
-            }
-        }
-
         if (!pages.isEmpty()) {
-            controller->setMode(Controller::Mode::Pages);
-            controller->setPages(pages);
+            // Ensure each page ends with ".qml"
+            for (QString &page : pages) {
+                if (!page.endsWith(".qml")) {
+                    page.append(".qml");
+                }
+            }
+
+            appSingleton->setMode(App::Mode::Pages);
+            appSingleton->setPages(pages);
         }
     } else if (parser.isSet(QStringLiteral("post-update"))) {
-        controller->setMode(Controller::Mode::Update);
-    } else if (parser.isSet(QStringLiteral("post-update-beta"))) {
-        controller->setMode(Controller::Mode::Beta);
+        appSingleton->setMode(App::Mode::Update);
     } else if (parser.isSet(QStringLiteral("live-environment"))) {
-        controller->setMode(Controller::Mode::Live);
+        appSingleton->setMode(App::Mode::Live);
     }
 
-    engine.loadFromModule("org.kde.plasma.welcome", "Main");
+    engine.loadFromModule("org.kde.plasma.welcome.private", "Main");
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
